@@ -3,6 +3,7 @@ import os
 import re
 from datetime import datetime, timedelta
 from typing import (
+    AsyncContextManager,
     AsyncIterator,
     Generic,
     Iterable,
@@ -34,8 +35,8 @@ from neuro_sdk import (
     ResourceNotFound,
     TagOption,
 )
-from neuro_sdk.utils import AsyncContextManager, asyncgeneratorcontextmanager
 
+from .asyncio_utils import asyncgeneratorcontextmanager
 from .parse_utils import (
     JobTableFormat,
     parse_ps_columns,
