@@ -1,11 +1,11 @@
 import datetime
-from typing import Callable, Optional
+from typing import Callable, Optional, overload
 
 import humanize
+from typing_extensions import Protocol
 from yarl import URL
 
-from neuro_sdk import RemoteImage
-from neuro_sdk.url_utils import CLUSTER_SCHEMES
+from neuro_sdk import SCHEMES, RemoteImage
 
 URIFormatter = Callable[[URL], str]
 ImageFormatter = Callable[[RemoteImage], str]
@@ -13,7 +13,7 @@ ImageFormatter = Callable[[RemoteImage], str]
 
 def uri_formatter(username: str, cluster_name: str) -> URIFormatter:
     def formatter(uri: URL) -> str:
-        if uri.scheme in CLUSTER_SCHEMES:
+        if uri.scheme in SCHEMES:
             if uri.host == cluster_name:
                 assert uri.path[0] == "/"
                 path = uri.path.lstrip("/")
@@ -57,24 +57,75 @@ def format_timedelta(delta: datetime.timedelta) -> str:
     )
 
 
-def format_datetime_iso(when: Optional[datetime.datetime]) -> str:
+def format_datetime_iso(
+    when: Optional[datetime.datetime], *, precise: bool = False
+) -> str:
     if when is None:
         return ""
     return when.isoformat()
 
 
-def format_datetime_human(when: Optional[datetime.datetime]) -> str:
+def format_datetime_human(
+    when: Optional[datetime.datetime],
+    *,
+    precise: bool = False,
+    timezone: Optional[datetime.timezone] = None,
+) -> str:
+    """Humanizes the datetime
+
+    When not in precise mode (precise=False), prints number of largest units
+    for moments that are less then a day ago, and date just day otherwise:
+
+    "32 seconds ago"
+    "5 minutes ago"
+    "11 hours age"
+    "yesterday"
+    "Jan 1"
+
+    In precise mode (precise=True), prints two largest units for moments
+    that are less then a day ago, and date with time otherwise:
+
+    "32 seconds ago"
+    "5 minutes and 22 seconds ago"
+    "5 hours and 31 minutes ago"
+    "yesterday at 14:22"
+    "Jan 1 at 00:01"
+    """
     if when is None:
         return ""
     assert when.tzinfo is not None
     delta = datetime.datetime.now(datetime.timezone.utc) - when
     if delta < datetime.timedelta(days=1):
+        if precise:
+            min_unit = "seconds"
+            if delta > datetime.timedelta(hours=1):
+                min_unit = "minutes"
+            return (
+                humanize.precisedelta(delta, minimum_unit=min_unit, format="%0.0f")
+                + " ago"
+            )
         return humanize.naturaltime(delta)
     else:
-        return humanize.naturaldate(when.astimezone())
+        when_local = when.astimezone(timezone)
+        result = humanize.naturaldate(when_local)
+        if precise:
+            result = f"{result} at {when_local.strftime('%H:%M')} "
+        return result
 
 
-DatetimeFormatter = Callable[[Optional[datetime.datetime]], str]
+class DatetimeFormatter(Protocol):
+    @overload
+    def __call__(self, when: Optional[datetime.datetime]) -> str:
+        ...
+
+    @overload
+    def __call__(self, when: Optional[datetime.datetime], *, precise: bool) -> str:
+        ...
+
+    def __call__(
+        self, when: Optional[datetime.datetime], *, precise: bool = True
+    ) -> str:
+        ...
 
 
 def get_datetime_formatter(use_iso_format: bool) -> DatetimeFormatter:
