@@ -5,6 +5,7 @@ import logging
 import shlex
 import sys
 import webbrowser
+from contextlib import AsyncExitStack
 from datetime import datetime, timedelta, timezone
 from typing import AsyncIterator, List, Optional, Sequence, Set, Tuple
 
@@ -69,7 +70,6 @@ from .parse_utils import (
 )
 from .root import Root
 from .utils import (
-    AsyncExitStack,
     argument,
     calc_life_span,
     command,
@@ -760,7 +760,7 @@ async def top(
         await asyncio.gather(create_pollers(), renderer())
 
 
-@command(deprecated=True, hidden=True)
+@command()
 @argument("job", type=JOB)
 @argument("image", type=RemoteImageType())
 async def save(root: Root, job: str, image: RemoteImage) -> None:
