@@ -44,25 +44,25 @@ def time_ctl() -> TimeCtl:
     return TimeCtl()
 
 
-def test_format_url_storage() -> None:
+def test_format_url_storage(root: Root) -> None:
     u = URL("storage://asvetlov/folder")
-    assert format_url(u) == "storage://asvetlov/folder"
+    assert format_url(root, u) == "storage://asvetlov/folder"
 
 
-def test_format_url_file() -> None:
+def test_format_url_file(root: Root) -> None:
     u = URL("file:///asvetlov/folder")
     if sys.platform == "win32":
         expected = "\\asvetlov\\folder"
     else:
         expected = "/asvetlov/folder"
-    assert format_url(u) == expected
+    assert format_url(root, u) == expected
 
 
 _MakeRoot = Callable[[bool, bool, bool], Root]
 
 
 @pytest.fixture
-def make_root(new_console: NewConsole) -> Iterator[_MakeRoot]:
+def make_root(new_console: NewConsole, nmrc_path: Path) -> Iterator[_MakeRoot]:
     root = None
 
     def make(color: bool, tty: bool, verbose: bool) -> Root:
@@ -72,7 +72,7 @@ def make_root(new_console: NewConsole) -> Iterator[_MakeRoot]:
             tty,
             True,
             60,
-            Path("~/.neuro"),
+            config_path=nmrc_path,
             verbosity=int(verbose),
             trace=False,
             trace_hide_token=True,
@@ -85,6 +85,7 @@ def make_root(new_console: NewConsole) -> Iterator[_MakeRoot]:
         )
         root.console = new_console(tty=tty, color=color)
         root.err_console = new_console(tty=tty, color=color)
+        root.run(root.init_client())
         return root
 
     yield make
